package dev.fyloz.colorrecipesexplorer.service.jobs

import dev.fyloz.colorrecipesexplorer.service.TouchUpKitService
import org.slf4j.Logger
import org.springframework.context.annotation.Profile
import org.springframework.scheduling.annotation.Scheduled
import org.springframework.stereotype.Component

@Component
@Profile("!emergency")
class TouchUpKitRemover(
    private val touchUpKitService: TouchUpKitService,
    private val logger: Logger
) {
    @Scheduled(cron = "0 0 0 * * *")
    fun execute() {
        removeExpiredKits()
    }

    private fun removeExpiredKits() {
        logger.info("Removing expired touch up kits...")
        with(touchUpKitService.getAll().filter(touchUpKitService::isExpired)) {
            this.forEach(touchUpKitService::delete)
            logger.info("Removed ${this.size} expired touch up kits")
        }
    }
}
